@@ -2,33 +2,42 @@ package Dancer2::Template::Xslate;
 
 use v5.10;
 use strict;
-use warnings FATAL => "all";
+use warnings FATAL => 'all';
 use utf8;
 
-use Carp;
 use Moo;
-use Dancer2::Core::Types;
-use Dancer2::FileUtils qw(read_file_content);
-use File::Spec::Functions qw(splitpath);
-use Text::Xslate;
 
-our $VERSION = 'v0.0.3'; # VERSION
+use Carp qw(croak);
+use Dancer2 0.06 ();
+use Dancer2::Core::Types qw(InstanceOf);
+use Text::Xslate;
+use File::Spec::Functions qw(abs2rel file_name_is_absolute);
+
+
+our $VERSION = 'v0.0.5'; # VERSION
 # ABSTRACT: Text::Xslate template engine for Dancer2
 
-with "Dancer2::Core::Role::Template";
+with 'Dancer2::Core::Role::Template';
 
-has "+engine" => (
-    isa => InstanceOf["Text::Xslate"]
+has '+default_tmpl_ext' => (
+    default => sub { 'tx' }
 );
-has "+default_tmpl_ext" => (
-    default => sub {"tx"},
+has '+engine' => (
+    isa => InstanceOf['Text::Xslate']
 );
 
 sub _build_engine {
     my ($self) = @_;
 
-    # Set a default path that is overridable by the engine config:
-    return Text::Xslate->new(path => ["/"], %{ $self->config });
+    my %config = %{ $self->config };
+
+    # Dancer2 inject a couple options without asking; Text::Xslate protests:
+    delete $config{environment};
+    if ( my $location = delete $config{location} ) {
+        $config{path} //= [$location];
+    }
+
+    return Text::Xslate->new(%config);
 }
 
 sub render {
@@ -36,11 +45,14 @@ sub render {
 
     my $xslate = $self->engine;
     my $content = eval {
-        if ( ref($tmpl) eq "SCALAR" ) {
+        if ( ref($tmpl) eq 'SCALAR' ) {
             $xslate->render_string($$tmpl, $vars)
         }
         else {
-            $xslate->render($tmpl, $vars);
+            my $rel_path = file_name_is_absolute($tmpl)
+                ? abs2rel($tmpl)
+                : $tmpl;
+            $xslate->render($rel_path, $vars);
         }
     };
 
